@@ -4,6 +4,7 @@ __all__ = [
     "Block",
     "ByteBlock",
     "ByteInterval",
+    "CFG",
     "CfgNode",
     "CodeBlock",
     "DataBlock",
@@ -25,7 +26,7 @@ __all__ = [
 from .auxdata import AuxData, AuxDataContainer
 from .block import Block, ByteBlock, CfgNode, CodeBlock, DataBlock, ProxyBlock
 from .byteinterval import ByteInterval
-from .cfg import Edge
+from .cfg import CFG, Edge
 from .ir import IR
 from .module import Module
 from .node import Node
